==> ara_tools-0.1.4.17-py3-none-any.whl: ara_tools/templates/prompt-creation/prompts/template_feature.md <==
# Prompt

Please replace this whole text with a prompt that includes a feature description!
Here an example as to what information you could include when creating the prompt:

# Feature Description

## Overview

**Please replace this text with a comprehensive description of the feature you are developing.** This description should focus on the behavior and outcomes from a user's perspective. It's essential to articulate the feature in a way that highlights user interactions and the benefits they derive from it.

### Key Points to Cover:

- **Objective**: What is the primary purpose of this feature? How does it benefit the user or address a specific need?
- **Behavioral Description**: Describe the expected behaviors of this feature. What will the feature enable the user to do?
- **Acceptance Criteria**: What are the specific conditions that must be met for this feature to be considered complete and functioning as expected?

## User Stories

Incorporate relevant user stories here. User stories are instrumental in BDD and should follow the standard format:

- As a [type of user], I want [some goal] so that [some reason].

These stories help to frame the feature in terms of user value and actionable outcomes.

## Scenarios

Outline potential scenarios for this feature, expressed in Given-When-Then format. These scenarios will form the basis for your test cases in BDD. For example:

- Given [some initial context], 
  When [an event occurs], 
  Then [ensure some outcomes].

## Additional Notes

Include any other pertinent information or notes that will aid in the development, implementation, and testing of this feature. This might encompass constraints, dependencies, or any assumptions that are relevant to understanding the feature's context.

==> ara_tools-0.1.4.19-py3-none-any.whl: ara_tools/templates/prompt-creation/prompts/template_feature.md <==
# prompt

Please replace this whole text with a prompt that includes a feature description!
Here an example as to what information you could include when creating the prompt:

## Feature Description

### Overview

**Please replace this text with a comprehensive description of the feature you are developing.** This description should focus on the behavior and outcomes from a user's perspective. It's essential to articulate the feature in a way that highlights user interactions and the benefits they derive from it.

#### Key Points to Cover:

- **Objective**: What is the primary purpose of this feature? How does it benefit the user or address a specific need?
- **Behavioral Description**: Describe the expected behaviors of this feature. What will the feature enable the user to do?
- **Acceptance Criteria**: What are the specific conditions that must be met for this feature to be considered complete and functioning as expected?

### User Stories

Incorporate relevant user stories here. User stories are instrumental in BDD and should follow the standard format:

- As a [type of user], I want [some goal] so that [some reason].

These stories help to frame the feature in terms of user value and actionable outcomes.

### Scenarios

Outline potential scenarios for this feature, expressed in Given-When-Then format. These scenarios will form the basis for your test cases in BDD. For example:

- Given [some initial context], 
  When [an event occurs], 
  Then [ensure some outcomes].

### Additional Notes

Include any other pertinent information or notes that will aid in the development, implementation, and testing of this feature. This might encompass constraints, dependencies, or any assumptions that are relevant to understanding the feature's context.
